| get_extrato | R Documentation |
Retrieves the extract of report deliveries for a given entity and reference year. Useful for checking which reports have been submitted and their status (approved, rectified, etc.).
get_extrato(
id_ente,
an_referencia,
use_cache = TRUE,
verbose = FALSE,
page_size = NULL,
max_rows = Inf
)
get_delivery_status(entity_id, year, use_cache = TRUE, verbose = FALSE,
page_size = NULL, max_rows = Inf)
id_ente |
Integer. IBGE code of the entity. Required. |
an_referencia |
Integer. Reference year (e.g., |
use_cache |
Logical. If |
verbose |
Logical. If |
page_size |
Integer or |
max_rows |
Numeric. Maximum number of rows to return. Defaults
to |
entity_id |
Integer. IBGE code of the entity. Required.
Maps to |
year |
Integer. Reference year (e.g., |
get_delivery_status() is an English alias for get_extrato().
A tibble with delivery status data including
columns such as exercicio, cod_ibge, instituicao, entregavel,
periodo, periodicidade, status_relatorio, data_status,
forma_envio, and tipo_relatorio.
Other SICONFI:
get_anexos(),
get_dca(),
get_dca_for_state(),
get_entes(),
get_msc_controle(),
get_msc_orcamentaria(),
get_msc_patrimonial(),
get_rgf(),
get_rgf_for_state(),
get_rreo(),
get_rreo_for_state()
## Not run:
extrato <- get_extrato(id_ente = 17, an_referencia = 2022)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.