| get_pvl | R Documentation |
Retrieves data from the Public Debt Verification Letters (PVL) system.
These are requests for approval of credit operations and debt by
subnational entities. Use the resulting id_pleito column to query
detail functions like get_pvl_tramitacao(), get_opc_cronograma_liberacoes(),
etc.
get_pvl(
uf = NULL,
tipo_interessado = NULL,
id_ente = NULL,
use_cache = TRUE,
verbose = FALSE,
page_size = NULL,
max_rows = Inf
)
get_debt_requests(state = NULL, entity_type = NULL,
entity_id = NULL, use_cache = TRUE, verbose = FALSE,
page_size = NULL, max_rows = Inf)
uf |
Character. State abbreviation (e.g., |
tipo_interessado |
Character. Type of requesting entity (e.g.,
|
id_ente |
Integer. IBGE code of the requesting entity. Optional. |
use_cache |
Logical. If |
verbose |
Logical. If |
page_size |
Integer or |
max_rows |
Numeric. Maximum number of rows to return. Defaults
to |
state |
Character. State abbreviation (e.g., |
entity_type |
Character. Type of requesting entity (e.g.,
|
entity_id |
Integer. IBGE code of the requesting entity. Optional.
Maps to |
get_debt_requests() is an English alias.
A tibble with PVL data including id_pleito,
tipo_interessado, interessado, cod_ibge, uf, status,
tipo_operacao, finalidade, credor, valor, and more.
Other SADIPEM:
get_opc_cronograma_liberacoes(),
get_opc_cronograma_pagamentos(),
get_opc_taxa_cambio(),
get_pvl_tramitacao(),
get_res_cdp(),
get_res_cronograma_pagamentos()
## Not run:
# Search all PVLs for Pernambuco
pvl_pe <- get_pvl(uf = "PE")
# Search by IBGE code (Recife)
pvl_recife <- get_pvl(id_ente = 2611606)
# Use id_pleito from results for detail queries:
id <- pvl_pe$id_pleito[1]
pagamentos <- get_opc_cronograma_pagamentos(id_pleito = id)
cdp <- get_res_cdp(id_pleito = id)
# For PVL processing status, filter approved PVLs first:
deferidos <- pvl_pe[pvl_pe$status == "Deferido", ]
if (nrow(deferidos) > 0) {
status <- get_pvl_tramitacao(id_pleito = deferidos$id_pleito[1])
}
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.