Skip to contents

These functions were renamed in tesouror 0.3.0 and are kept as thin wrappers for backward compatibility. They forward to their replacements and emit a .Deprecated() warning. Please migrate to the new names:

Usage

get_dca(...)

get_annual_accounts(...)

get_dca_for_state(...)

get_annual_accounts_for_state(...)

get_rreo(...)

get_budget_report(...)

get_rreo_for_state(...)

get_budget_report_for_state(...)

get_rgf(...)

get_fiscal_report(...)

get_rgf_for_state(...)

get_fiscal_report_for_state(...)

Arguments

...

Arguments forwarded to the replacement function.

Value

The value returned by the replacement function.

Details

DeprecatedReplacement
get_dca()get_dca_ufs()
get_annual_accounts()get_annual_accounts_ufs()
get_dca_for_state()get_dca_municipios()
get_annual_accounts_for_state()get_annual_accounts_municipalities()
get_rreo()get_rreo_ufs()
get_budget_report()get_budget_report_ufs()
get_rreo_for_state()get_rreo_municipios()
get_budget_report_for_state()get_budget_report_municipalities()
get_rgf()get_rgf_ufs()
get_fiscal_report()get_fiscal_report_ufs()
get_rgf_for_state()get_rgf_municipios()
get_fiscal_report_for_state()get_fiscal_report_municipalities()