| get_rreo | R Documentation |
Retrieves data from the Budget Execution Summary Report (RREO) for specific filtering criteria. The RREO is published bimonthly and contains information about revenues, expenses, and other budgetary data.
get_rreo(
an_exercicio,
nr_periodo,
co_tipo_demonstrativo,
no_anexo,
co_esfera,
id_ente,
use_cache = TRUE,
verbose = FALSE,
page_size = NULL,
max_rows = Inf
)
get_budget_report(fiscal_year, period, report_type, appendix,
sphere, entity_id, use_cache = TRUE, verbose = FALSE,
page_size = NULL, max_rows = Inf)
an_exercicio |
Integer. Fiscal year (e.g., |
nr_periodo |
Integer. Bimester number (1-6). Required. |
co_tipo_demonstrativo |
Character. Report type: |
no_anexo |
Character. Appendix name (e.g., |
co_esfera |
Character. Government sphere: |
id_ente |
Integer. IBGE code of the entity. Required. |
use_cache |
Logical. If |
verbose |
Logical. If |
page_size |
Integer or |
max_rows |
Numeric. Maximum number of rows to return. Defaults
to |
fiscal_year |
Integer. Fiscal year (e.g., |
period |
Integer. Bimester number (1-6). Required.
Maps to |
report_type |
Character. Report type: |
appendix |
Character. Appendix name (e.g., |
sphere |
Character. Government sphere: |
entity_id |
Integer. IBGE code of the entity. Required.
Maps to |
get_budget_report() is an English-parameter alias for this function.
A tibble with RREO data including columns such as
exercicio, demonstrativo, periodo, periodicidade, instituicao,
cod_ibge, uf, populacao, anexo, rotulo, coluna, cod_conta,
conta, and valor.
Other SICONFI:
get_anexos(),
get_dca(),
get_dca_for_state(),
get_entes(),
get_extrato(),
get_msc_controle(),
get_msc_orcamentaria(),
get_msc_patrimonial(),
get_rgf(),
get_rgf_for_state(),
get_rreo_for_state()
## Not run:
rreo <- get_rreo(
an_exercicio = 2022, nr_periodo = 6,
co_tipo_demonstrativo = "RREO",
no_anexo = "RREO-Anexo 01",
co_esfera = "E", id_ente = 17
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.